require(ape, quietly = TRUE)
bird.orders <- read.tree("bird.orders.tre")
